#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-ansi-terminal
version:              1.1.4
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.4-EynbTVBvtsu8QE6iORmNaN
key:                  prettyprinter-ansi-terminal-1.1.4-EynbTVBvtsu8QE6iORmNaN
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  0155f7f09e9ad63023848203ce836c6c
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.4

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.4

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.4-EynbTVBvtsu8QE6iORmNaN
depends:
    ansi-terminal-1.1-1lvoyaiIx4qBBztkF1DGdA base-4.18.2.1
    prettyprinter-1.7.1-E27IB52rJzT5cRmoGOw0uk text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

